<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_EditAccount
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_EditAccount extends Moc10_Form
{

    /**
     * Form template
     * @var string
     */
    protected $_template = null;

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'fname' => null,
                                   'lname' => null,
                                   'email1' => null,
                                   'email2' => null,
                                   'username' => null,
                                   'password1' => null,
                                   'password2' => null,
                                   'cur_username' => null,
                                   'cur_email' => null,
                                   'verified' => null,
                                   'access' => null,
                                   'allowed' => null,
                                   'user_id' => 0);

    /**
     * Initialization method for the edit account form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'editAccountForm');
        $this->setAttributes('onsubmit', "return editAccountFrm.userValidate();");

        // Create the 'fname' form element.
        $fname = new Moc10_Form_Element('text', 'fname', $this->_postFields['fname']);
        $fname->setLabel($lang->__('First Name:'));
        $fname->setAttributes('size', '40');
        $fname->setRequired(true);

        // Create the 'lname' form element.
        $lname = new Moc10_Form_Element('text', 'lname', $this->_postFields['lname']);
        $lname->setLabel($lang->__('Last Name:'));
        $lname->setAttributes('size', '40');
        $lname->setRequired(true);

        // Create the 'email1' form element.
        $email1 = new Moc10_Form_Element('text', 'email1', $this->_postFields['email1']);
        $email1->setLabel($lang->__('Change Email:'));
        $email1->addValidator('Email');
        $email1->setAttributes('size', '40');

        // Create the 'email2' form element.
        $email2 = new Moc10_Form_Element('text', 'email2', $this->_postFields['email2']);
        $email2->setLabel($lang->__('Confirm New Email:'));
        $email2->addValidator('Email');
        $email2->setAttributes('size', '40');

        // If the form has been submitted, validate the emails.
        if ($this->_postFields['email1'] != '') {
            $email2->setRequired(true);
            $email2->addValidator('Equal', true, $this->_postFields['email1'], $lang->__('The emails do not match.'));
        }

        // Create the 'username' form element.
        $username = new Moc10_Form_Element('text', 'username', $this->_postFields['username']);
        $username->setLabel($lang->__('Username:'));
        $username->addValidator('AlphaNum');
        $username->addValidator('LengthGT', true, 3);
        $username->setAttributes('size', '40');
        $username->setAttributes('autocomplete', 'off');
        $username->setAttributes('onkeyup', "xmlhttp.getRequest('../core/process/check.username.php?current=" . $this->_postFields['username'] . "&username=' + this.value, checkUsername); return false;");
        $username->setRequired(true);

        // If the form has been submitted, validate the username.
        if ((!is_null($this->_postFields['username'])) && ($this->_postFields['username'] != $this->_postFields['cur_username'])) {
            $dupe_user = new Phire_Table_Users();
            $dupe_user->findBy('username', $this->_postFields['username']);
            if (isset($dupe_user->user_id)) {
                $username->addValidator('NotEqual', true, $dupe_user->username, $lang->__('That username already exists.'));
            }
        }

        // Create the 'password1' form element.
        $password1 = new Moc10_Form_Element('password', 'password1', $this->_postFields['password1']);
        $password1->setLabel($lang->__('Change Password:'));
        $password1->addValidator('LengthGT', true, 5);
        $password1->setAttributes('size', '20');

        // Create the 'password2' form element.
        $password2 = new Moc10_Form_Element('password', 'password2', $this->_postFields['password2']);
        $password2->setLabel($lang->__('Re-type New Password:'));
        $password2->addValidator('LengthGT', true, 5);
        $password2->setAttributes('size', '20');

        // If the form has been submitted, validate the passwords.
        if ($this->_postFields['password1'] != '') {
            $password2->setRequired(true);
            $password2->addValidator('Equal', true, $this->_postFields['password1'], $lang->__('The passwords do not match.'));
        }

        // Create the 'cur_username' form element.
        $cur_username = new Moc10_Form_Element('hidden', 'cur_username', $this->_postFields['cur_username']);

        // Create the 'cur_email' form element.
        $cur_email = new Moc10_Form_Element('hidden', 'cur_email', $this->_postFields['cur_email']);

        // Create the 'user_id' form element.
        $user_id = new Moc10_Form_Element('hidden', 'user_id', $this->_postFields['user_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('class', 'submitBtn');
        $submit->setAttributes('style', 'float: left;');

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($this->_template);
        $this->addElements(array($fname, $lname, $email1, $email2, $username, $password1, $password2, $user_id, $cur_username, $cur_email, $submit));

    }

    /**
     * Method to save the user data.
     *
     * @return void
     */
    public function saveData()
    {

        $lang = new Phire_Language();
        $config = new Phire_Table_Config();

        // Set and save the new user data.
        $user = new Phire_Table_Users();
        $user->findById($this->_postFields['user_id']);

        $user->fname = (string)Moc10_String::setString($this->_postFields['fname'])->dehtml();
        $user->lname = (string)Moc10_String::setString($this->_postFields['lname'])->dehtml();

        if ($this->_postFields['password1'] != '') {
            // Determine if user password encoding is activated.
            if ($config->settings['user_password_encoding'] != 'Off') {
                $password = ($config->settings['user_password_encoding'] == 'SHA1') ? sha1($this->_postFields['password1']) : md5($this->_postFields['password1']);
            } else {
                $password = $this->_postFields['password1'];
            }
        } else {
            $password = $user->password;
        }

        // If a new email is set, and user verification is required,
        // set the email address and build and send the verification email.
        if ($this->_postFields['email1'] != '') {
            $email = $this->_postFields['email1'];
            if ($config->settings['user_verification'] == 'On') {

                $verified = 'No';

                $rcpt = array(array('name' => $user->fname . ' ' . $user->lname,
                                    'email' => $email,
                                    'username' => $user->username,
                                    'password' => $password,
                                    'verify_link' => 'http://' . $_SERVER['HTTP_HOST'] . '/user/verify/' . $user->user_id . '/' . sha1($email),
                                    'login_link' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . SYS_PATH . '/'));

                $message = "[{name}],\n\n" . $lang->__('Your user account for the Phire CMS has been modified. Your current credentials for the Phire CMS are:') . "\n\n" . $lang->__('Username:') . " [{username}]\n" . $lang->__('Password:') . " [{password}]\n\n" . $lang->__('In order to access the account you must re-verify your email address. Please click on the link below to re-verify your email address:') . "\n[{verify_link}]\n\n" . $lang->__('Once successfully verified, you can then log in here:') . "\n[{login_link}]\n\n" . $lang->__('Thank You,') . "\n\n" . $lang->__('The Phire CMS Team') . "\n\n";

                $noreply = 'noreply@' . ((stripos($_SERVER['HTTP_HOST'], 'www.') !== false) ? str_replace('www.', '', $_SERVER['HTTP_HOST']) : $_SERVER['HTTP_HOST']);

                $mail = new Moc10_Mail($rcpt, null, $lang->__('Phire CMS User Account Modified - Verification Required'));
                $mail->setHeaders(array('From' => array($noreply, $noreply),
                                        'Reply-To' => array($noreply, $noreply)));

                $mail->setText($message);
                $mail->init();
                $mail->send();

            } else {
                $verified = $user->verified;
            }
        } else {
            $email = $user->email;
            $verified = 'Yes';
        }

        // Finalize user data and save.
        $user->email = $email;
        $user->username = $this->_postFields['username'];
        $user->password = $password;
        $user->verified = $verified;

        $user->save();

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['user_id']) && ($post['user_id'] != 0)) {

                $user = new Phire_Table_Users();
                $user->findById($post['user_id']);

                $this->_postFields['fname'] = (string)Moc10_String::setString($user->fname)->strip()->html();
                $this->_postFields['lname'] = (string)Moc10_String::setString($user->lname)->strip()->html();
                $this->_postFields['email1'] = null;
                $this->_postFields['email2'] = null;
                $this->_postFields['username'] = $user->username;
                $this->_postFields['password1'] = null;
                $this->_postFields['password2'] = null;
                $this->_postFields['verified'] = $user->verified;
                $this->_postFields['access'] = $user->access;
                $this->_postFields['allowed'] = Moc10_String::setString($user->allowed_sites)->split('|');
                $this->_postFields['cur_username'] = $user->username;
                $this->_postFields['cur_email'] = $user->email;
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['user_id'] = $user->user_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $back = $lang->__('Back');
        $blue = $lang->__('Blue fields are required.');
        $cur_email = $lang->__('Current Email:');
        $user_info = $lang->__('User Information');
        $user_pass = $lang->__('Username & Password');
        $user_4chars = $lang->__('Username must be alphanumeric and at least 4 characters in length.');
        $pass_6chars = $lang->__('Password must be at least 6 characters in length.');
        $access_settings = $lang->__('Access Settings');
        $ver = $lang->__('Verified:');
        $ver_set = $lang->__($this->_postFields['verified']);
        $acc = $lang->__('Access:');
        $acc_set = $lang->__($this->_postFields['access']);
        $cancel = $lang->__('CANCEL');

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = BASE_PATH . SYS_PATH . '/';
            $plg_cancel = null;
        }

        $all_sites = new Phire_Table_Sites();
        $all_sites->findAll();

        $all_sites_list = '';
        foreach ($all_sites->rows as $ste) {
            if (in_array($ste->site_id, $this->_postFields['allowed'])) {
                $all_sites_list .= $ste->site_domain . "<br />\n";
            }
        }

        $others = new Phire_Table_Users();
        $others->execute("SELECT * FROM " . DB_PREFIX . "users WHERE access = 'Admin' AND user_id != '" . (string)Moc10_String::setString($this->_postFields['user_id'])->escape(true)->striptags() . "'");

        if (isset($others->rows[0])) {
            $close = "<input style=\"float: left;\" type=\"checkbox\" class=\"checkBox\" name=\"close_acct[]\" id=\"close_acct\" value=\"Yes\" /> <span style=\"float: left; margin: 4px 0 0 5px;\">" . $lang->__('Check this box if you wish to close this account.') . "</span>\n<br /><div style=\"width: 400px; font-size: 0.85em; clear: both;\" class=\"error\">" . $lang->__('Checking this box will permanently close your account, removing all access to the system. You can only gain access again if an admin creates a new account for you.') . "</div>\n<br />";
        } else {
            $close = "&nbsp;";
        }

        // Define the main form template.
        $this->_template = <<<FORMTEMP
            <style type="text/css">
                .radioPad {
                    float: left;
                    margin: 0;
                    padding: 0 18px 0 4px;
                }
            </style>
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        <strong style="padding-left: 25px;">{$user_info}</strong>
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td class="textTopRight">
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{fname_label}]
                                </td>
                                <td>
                                    [{fname}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{lname_label}]
                                </td>
                                <td>
                                    [{lname}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    <strong>{$cur_email}</strong>
                                </td>
                                <td>
                                    {$this->_postFields['cur_email']}
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{email1_label}]
                                </td>
                                <td>
                                    [{email1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{email2_label}]<br /><br /><br />
                                </td>
                                <td>
                                    [{email2}]<br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$user_pass}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;<br />
                                </td>
                                <td>
                                    <br /><em>{$user_4chars}</em><br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{username_label}]
                                </td>
                                <td>
                                    [{username}]
                                    <div id="usernameDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <em>{$pass_6chars}</em><br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{password1_label}]
                                </td>
                                <td>
                                    [{password1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{password2_label}]<br /><br /><br />
                                </td>
                                <td>
                                    [{password2}]<br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$access_settings}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    <strong>{$ver}</strong>
                                </td>
                                <td>
                                    <br />
                                    {$ver_set}
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <strong>{$acc}</strong>
                                </td>
                                <td>
                                    {$acc_set}
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    <strong>Allowed Sites:</strong>
                                </td>
                                <td style="vertical-align: top;">
                                    {$all_sites_list}
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    &nbsp;
                                </td>
                                <td style="vertical-align: top;">
                                    {$close}
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    [{submit}] [{user_id}] [{cur_username}] [{cur_email}] <a style="float: left; margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em;" class="submitGrayBtn" href="../core/process/edit.account.php?action=cancel{$plg_cancel}">{$cancel}</a> {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            editAccountFormInit();
                            var xmlhttp = new JaxXmlHttp();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
