<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Forgot
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Forgot extends Moc10_Form
{

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null);

    /**
     * User object
     * @var Phire_Table_Users
     */
    public $user = null;

    /**
     * Config settings object
     * @var Phire_Table_Config
     */
    public $config = null;

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('email' => null, 'mobile' => null);

    /**
     * Initialization method for the forgot form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();
        $this->config = new Phire_Table_Config();
        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'forgotForm');

        // Create the 'email' form element.
        $email = new Moc10_Form_Element('text', 'email', (string)Moc10_String::setString($this->_postFields['email'])->escape()->striptags());
        $email->setLabel($lang->__('Email:'));
        $email->addValidator('Email');
        $email->setRequired(true);

        // If the form has been submitted, verify the email.
        if (!is_null($this->_postFields['email'])) {
            $this->user = new Phire_Table_Users();
            $this->user->findBy('email', $this->_postFields['email']);
            if (!isset($this->user->user_id)) {
                $email->addValidator('NotEqual', true, $this->_postFields['email'], $lang->__('That email could not be found.'));
            }
        }

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SEND'));

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
            $email->setAttributes('size', '30');
            $this->setTemplate($this->_templates['mobile']);
            $submit->setAttributes('class', 'submitBtn');
        } else {
            $this->setAttributes('onsubmit', "return forgotFrm.validate();");
            $email->setAttributes('size', '40');
            $this->setTemplate($this->_templates['main']);
            $submit->setAttributes('class', 'submitBtn');
            $submit->setAttributes('style', 'float: right;');
        }

        // Add the form element objects to the form.
        $this->addElements(array($email, $submit));

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            foreach ($post as $key => $value) {
                if (array_key_exists($key, $this->_postFields)) {
                    $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $forgot = $lang->__('Forgot Your Password?');
        $msg = $lang->__('Please enter your email address, and a password reminder will be sent.');

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="forgotTable" cellspacing="0" cellpadding="0">
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <h2 class="blueHeader" style="margin-left: 0;">{$forgot}</h2>
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <span>{$msg}</span>
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{email_label}]
                    </td>
                    <td>
                        [{email}]
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        [{submit}]
                    </td>
                </tr>
            </table>
            <script type="text/javascript">
                forgotFormInit();
                forgotFrm.fo.email.focus();
            </script>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="forgotTable" cellspacing="0" cellpadding="0">
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <h2 class="blueHeader" style="margin-left: 0;">{$forgot}</h2>
                    </td>
                </tr>
                <tr>
                    <td style="width: 20%;">
                        &nbsp;
                    </td>
                    <td style="width: 80%;">
                        <span>{$msg}</span>
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{email_label}]
                    </td>
                    <td>
                        [{email}]
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        [{submit}] {$mobile}
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
